"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.Script = Script;
exports.scriptCache = exports.ScriptStrategy = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireWildcard(require("react"));

var _partytownContext = require("./partytown-context");

var _requestIdleCallbackShim = require("./request-idle-callback-shim");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

var ScriptStrategy; // eslint-disable-next-line @typescript-eslint/naming-convention

exports.ScriptStrategy = ScriptStrategy;

(function (ScriptStrategy) {
  ScriptStrategy["postHydrate"] = "post-hydrate";
  ScriptStrategy["idle"] = "idle";
  ScriptStrategy["offMainThread"] = "off-main-thread";
})(ScriptStrategy || (exports.ScriptStrategy = ScriptStrategy = {}));

var handledProps = new Set(["src", "strategy", "dangerouslySetInnerHTML", "children", "onLoad", "onError"]);
var scriptCache = new Set();
exports.scriptCache = scriptCache;

function Script(props) {
  var _ref = props || {},
      src = _ref.src,
      _ref$strategy = _ref.strategy,
      strategy = _ref$strategy === void 0 ? ScriptStrategy.postHydrate : _ref$strategy,
      onLoad = _ref.onLoad,
      onError = _ref.onError;

  var _useContext = (0, _react.useContext)(_partytownContext.PartytownContext),
      collectScript = _useContext.collectScript;

  (0, _react.useEffect)(function () {
    var script;

    switch (strategy) {
      case ScriptStrategy.postHydrate:
        script = injectScript(props);
        break;

      case ScriptStrategy.idle:
        (0, _requestIdleCallbackShim.requestIdleCallback)(function () {
          script = injectScript(props);
        });
        break;

      case ScriptStrategy.offMainThread:
        if (typeof window !== "undefined" && collectScript) {
          var attributes = resolveAttributes(props);
          collectScript(attributes);
        }

        break;
    }

    return function () {
      var _script3;

      if (onLoad) {
        var _script;

        (_script = script) === null || _script === void 0 ? void 0 : _script.removeEventListener("load", onLoad);
      }

      if (onError) {
        var _script2;

        (_script2 = script) === null || _script2 === void 0 ? void 0 : _script2.removeEventListener("error", onError);
      }

      (_script3 = script) === null || _script3 === void 0 ? void 0 : _script3.remove();
    };
  }, []);

  if (strategy === ScriptStrategy.offMainThread) {
    var inlineScript = resolveInlineScript(props);
    var attributes = resolveAttributes(props);

    if (typeof window === "undefined" && collectScript) {
      collectScript(attributes);
    }

    if (inlineScript) {
      return /*#__PURE__*/_react.default.createElement("script", (0, _extends2.default)({
        type: "text/partytown",
        async: true,
        "data-strategy": strategy
      }, attributes, {
        dangerouslySetInnerHTML: {
          __html: resolveInlineScript(props)
        }
      }));
    }

    return /*#__PURE__*/_react.default.createElement("script", (0, _extends2.default)({
      type: "text/partytown",
      async: true,
      src: proxyPartytownUrl(src),
      "data-strategy": strategy
    }, attributes));
  }

  return null;
}

function injectScript(props) {
  var _ref2 = props || {},
      id = _ref2.id,
      src = _ref2.src,
      _ref2$strategy = _ref2.strategy,
      strategy = _ref2$strategy === void 0 ? ScriptStrategy.postHydrate : _ref2$strategy,
      onLoad = _ref2.onLoad,
      onError = _ref2.onError;

  if (scriptCache.has(id || src)) {
    return null;
  }

  var inlineScript = resolveInlineScript(props);
  var attributes = resolveAttributes(props);
  var script = document.createElement("script");

  if (id) {
    script.id = id;
  }

  script.dataset.strategy = strategy;

  for (var _i = 0, _Object$entries = Object.entries(attributes); _i < _Object$entries.length; _i++) {
    var _Object$entries$_i = _Object$entries[_i],
        key = _Object$entries$_i[0],
        value = _Object$entries$_i[1];
    script.setAttribute(key, value);
  }

  if (inlineScript) {
    script.textContent = inlineScript;
  }

  if (src) {
    script.src = src;
  }

  if (onLoad) {
    script.addEventListener("load", onLoad);
  }

  if (onError) {
    script.addEventListener("error", onError);
  }

  document.body.appendChild(script);
  scriptCache.add(id || src);
  return script;
}

function resolveInlineScript(props) {
  var _ref3 = props || {},
      dangerouslySetInnerHTML = _ref3.dangerouslySetInnerHTML,
      _ref3$children = _ref3.children,
      children = _ref3$children === void 0 ? "" : _ref3$children;

  var _ref4 = dangerouslySetInnerHTML || {},
      _ref4$__html = _ref4.__html,
      dangerousHTML = _ref4$__html === void 0 ? "" : _ref4$__html;

  return dangerousHTML || children;
}

function resolveAttributes(props) {
  var attributes = {};

  for (var _i2 = 0, _Object$entries2 = Object.entries(props); _i2 < _Object$entries2.length; _i2++) {
    var _Object$entries2$_i = _Object$entries2[_i2],
        key = _Object$entries2$_i[0],
        value = _Object$entries2$_i[1];

    if (handledProps.has(key)) {
      continue;
    }

    attributes[key] = value;
  }

  return attributes;
}

function proxyPartytownUrl(url) {
  if (!url) {
    return undefined;
  }

  return "/__partytown-proxy?url=" + encodeURIComponent(url);
}